nros_platform_task_cancel

Function nros_platform_task_cancel 

pub unsafe extern "C" fn nros_platform_task_cancel(
    task: *mut c_void,
) -> i8
Request task to terminate at the next cancellation point. Cooperative: a task that never reaches a cancel point will not stop.