CffiPlatform

Struct CffiPlatform 

pub struct CffiPlatform;
Zero-sized type implementing the platform traits via the canonical nros_platform_* C symbols.

The crate that pulls CffiPlatform into a final binary is responsible for ensuring the symbols are supplied at link time (either by a C translation unit or a Rust -cffi shim crate).